@@ -10,3 +10,10 @@ use crate::errors::{RustusError, RustusResult};
 pub async fn not_found() -> RustusResult<HttpResponse> {
     Err(RustusError::FileNotFound)
 }
+
+/// Checks that application is accepting connections correctly.
+#[allow(clippy::unused_async)]
+#[cfg_attr(coverage, no_coverage)]
+pub async fn health_check() -> HttpResponse {
+    HttpResponse::Ok().finish()
+}
